api.users.v1 package — Argus-Toolbelt 1.0 documentation

# api.users.v1 package

## Submodules

## api.users.v1.group module

Autogenerated API

`api.users.v1.group.` `find_groups`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 12, “limit”: 785, “responseCode”: 200, “count”: 504, “data”: [{“id”: 67, “userName”: “ritterethan”, “name”: “Robert Kelly”, “createdTimestamp”: 850341818, “createdByUser”: {“id”: 106, “customerID”: 729, “userName”: “csalazar”, “name”: “Amanda Lee”}, “lastUpdatedTimestamp”: 198995418, “lastUpdatedByUser”: {“id”: 35, “customerID”: 979, “userName”: “bryanpotter”, “name”: “Laura Morales”}, “properties”: {“additionalProperties”: “Thank material popular campaign must together admit.”}, “groupName”: “Entire friend sure include picture close.”, “description”: “Democrat interview religious yes thousand.”, “ascendantIDs”: [660], “flags”: [“AUTH_LDAP”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Water market level real scientist.”, “messageTemplate”: “Anyone within need education you.”, “field”: “Might wind return site every.”, “parameter”: {}, “timestamp”: 671908437}], “currentPage”: 639, “size”: 956}

`api.users.v1.group.` `get_gropu_by_id`(groupId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | groupId (int) – ID of group
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 313, “limit”: 49, “responseCode”: 200, “count”: 618, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “According something seat.”, “messageTemplate”: “Firm none have data call.”, “field”: “Probably serious American establish suddenly.”, “parameter”: {}, “timestamp”: 300097531}], “currentPage”: 937, “size”: 230}

`api.users.v1.group.` `get_group_by_name`(groupName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group profile by name (PUBLIC)

  Return type: | `dict`
  Parameters: | groupName (str) – Group shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 60, “limit”: 147, “responseCode”: 200, “count”: 135, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “International pull report high support alone nation become.”, “messageTemplate”: “Computer whose interesting notice future.”, “field”: “What tough player two body.”, “parameter”: {}, “timestamp”: 559418215}], “currentPage”: 80, “size”: 102}

`api.users.v1.group.` `list_groups`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group information (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of groups offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 258, “limit”: 985, “responseCode”: 200, “count”: 706, “data”: [{“id”: 717, “customerID”: 880, “description”: “Case artist economic skin.”, “name”: “Daryl White”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hair property tonight economic yourself ball.”, “messageTemplate”: “Official run notice into significant.”, “field”: “Perhaps thank east.”, “parameter”: {}, “timestamp”: 597471013}], “currentPage”: 323, “size”: 882}

## api.users.v1.subject module

Autogenerated API

`api.users.v1.subject.` `find_subjects`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search user or group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 764, “limit”: 197, “responseCode”: 200, “count”: 194, “data”: [{“id”: 152, “customerID”: 990, “name”: “Seth Yoder”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Look ago meeting Mr risk tend arrive.”, “messageTemplate”: “Bring serve describe recent concern few industry five.”, “field”: “Course position science turn wrong.”, “parameter”: {}, “timestamp”: 1325252729}], “currentPage”: 614, “size”: 872}

`api.users.v1.subject.` `get_subject_by_id`(subjectID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (int) – ID of subject
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 859, “limit”: 599, “responseCode”: 200, “count”: 387, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “History society firm degree anyone dream claim.”, “messageTemplate”: “Night poor quality.”, “field”: “Suggest could can success water reveal.”, “parameter”: {}, “timestamp”: 97739102}], “currentPage”: 686, “size”: 549}

`api.users.v1.subject.` `get_subject_by_name`(subjectName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profile by name (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectName (str) – Username or group shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 203, “limit”: 59, “responseCode”: 200, “count”: 433, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Evening any teacher way television ground seek.”, “messageTemplate”: “Voice article challenge moment contain base.”, “field”: “Worker music those consider spend.”, “parameter”: {}, “timestamp”: 1210460966}], “currentPage”: 140, “size”: 650}

`api.users.v1.subject.` `list_subjects`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of subjects offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 668, “limit”: 670, “responseCode”: 200, “count”: 349, “data”: [{“id”: 616, “customerID”: 852, “name”: “Ross Pittman”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Section approach low child something of too.”, “messageTemplate”: “Now actually sense consumer strategy computer interesting.”, “field”: “Tonight old nice talk.”, “parameter”: {}, “timestamp”: 86819182}], “currentPage”: 414, “size”: 920}

## api.users.v1.user module

Autogenerated API

`api.users.v1.user.` `check_permission`(userId: int, function: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Validate user permission to perform function (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user function (str) – Function name
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 ForbiddenPermissionException – on 403 UserNotFoundException – on 404
  Returns: | {}

`api.users.v1.user.` `find_users`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search user profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 753, “limit”: 372, “responseCode”: 200, “count”: 568, “data”: [{“id”: 352, “customerID”: 219, “userName”: “veronica01”, “name”: “Mrs. Sharon Smith DDS”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Physical score another create first seek matter.”, “messageTemplate”: “Great budget laugh student place once position.”, “field”: “Travel our knowledge how usually.”, “parameter”: {}, “timestamp”: 1170001423}], “currentPage”: 437, “size”: 113}

`api.users.v1.user.` `get_functions`(userId: int, onlyRoles: bool = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List a user’s permission functions regardless of customer (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user onlyRoles (bool) – Only return functions marked as roles keywords (list) – Filter functions by keywords on name and description offset (int) – Skip a number of functions limit (int) – Maximum number of returned functions
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 62, “limit”: 550, “responseCode”: 200, “count”: 666, “data”: [{“id”: 31, “name”: “Darrell Lopez”, “description”: “Behind let crime become.”, “securityLevel”: “ADMINISTRATIVE”, “flags”: [“ROLE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “International before rock various single into able.”, “messageTemplate”: “Common wife western.”, “field”: “Significant design professional become hand.”, “parameter”: {}, “timestamp”: 1036642439}], “currentPage”: 64, “size”: 467}

`api.users.v1.user.` `get_profile`(userId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 292, “limit”: 757, “responseCode”: 200, “count”: 817, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Create student natural program six attorney.”, “messageTemplate”: “Paper tree much where business cup.”, “field”: “Look stand baby manager knowledge dark market leg.”, “parameter”: {}, “timestamp”: 1166105631}], “currentPage”: 116, “size”: 212}

`api.users.v1.user.` `get_user_by_username`(userName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profile by username (PUBLIC)

  Return type: | `dict`
  Parameters: | userName (str) – Username
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 110, “limit”: 468, “responseCode”: 200, “count”: 573, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Traditional coach in he.”, “messageTemplate”: “Answer its run tell.”, “field”: “Order west meet little.”, “parameter”: {}, “timestamp”: 1299852476}], “currentPage”: 957, “size”: 602}

`api.users.v1.user.` `get_user_customers`(userId: int, offset: int = None, keywords: list = None, keywordField: list = None, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List a user’s customers. (DEV)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user offset (int) – Offset results keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search limit (int) – Limit results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 610, “limit”: 642, “responseCode”: 200, “count”: 815, “data”: [{“id”: 17, “name”: “Elizabeth Mccullough”, “shortName”: “Finally pretty red.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ball of computer few his between compare.”, “messageTemplate”: “Person list I fight trial still car.”, “field”: “Outside two because charge husband.”, “parameter”: {}, “timestamp”: 1045205275}], “currentPage”: 210, “size”: 507}

`api.users.v1.user.` `list_users`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of users offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 849, “limit”: 450, “responseCode”: 200, “count”: 440, “data”: [{“id”: 97, “customerID”: 687, “userName”: “arobinson”, “name”: “Margaret Green”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Possible above reflect.”, “messageTemplate”: “Unit scene civil sea give.”, “field”: “Record something follow above up.”, “parameter”: {}, “timestamp”: 109259293}], “currentPage”: 584, “size”: 932}

`api.users.v1.user.` `update_profile_picture_for_user`(userId: int, picture: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Upload and modify the user image (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user to change image for picture (str) – Image data URL
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 320, “limit”: 107, “responseCode”: 200, “count”: 660, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Bank staff clearly someone federal.”, “messageTemplate”: “Manager describe wrong rise recognize recently budget.”, “field”: “Child article seem sister shake stuff look.”, “parameter”: {}, “timestamp”: 1153575697}], “currentPage”: 25, “size”: 233}

## Module contents